<?php
/*
 * Copyright(c) 2015 PAYDESIGN, Inc. All rights reserved.
 * http://www.paydesign.co.jp/
 */

namespace Plugin\PayDesign\Form\Type;

use Plugin\PayDesign\Controller\Util\CommonUtil;
use Plugin\PayDesign\Controller\Util\PluginUtil;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormError;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\Validator\Constraints as Assert;

class AdminPeriodicInfoEditType extends AbstractType
{
    private $app;

    public function __construct(\Eccube\Application $app)
    {
        $this->app = $app;
    }

    /**
     * Build config type form
     *
     * @param FormBuilderInterface $builder
     * @param array $options
     * @return type
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $app = $this->app;
        $config = $app['config'];
        $prefAll = $app['eccube.repository.master.pref']->findAll();
        foreach( $prefAll as $val ) { $pref[$val["id"]] = $val["name"]; }

        // 申込状況一覧を取得
        $objPluginUtil =& PluginUtil::getInstance($this->app);
        $objPluginUtil->install();
        $arrPeriodicStatus = $objPluginUtil->getPeriodicStatus();

        $objCommonUtil = new CommonUtil();
        $arrPeriodicInterval = $objCommonUtil->getMonthSelectParameter('ヶ月');
        $arrCreateDay = $objCommonUtil->getDaySelectParameter('日');

        $builder
            ->add('periodic_next_date', 'date', array(
                'label' => '次回注文日',
                'required' => true,
                'input' => 'datetime',
                'widget' => 'single_text',
                'format' => 'yyyy-MM-dd',
            ))
            ->add('periodic_status', 'choice', array(
                'label' => '申込状況',
                'required' => false,
                'choices' => $arrPeriodicStatus,
                'empty_value' => '申込状況を選択してください',
                'empty_data' => '',
                'constraints' => array(
                    new Assert\NotBlank(array('message' => '申込状況が選択されていません。')),
                ),
            ))
            ->add('periodic_interval', 'choice', array(
                'label' => '購入間隔',
                'choices' => $arrPeriodicInterval,
                'multiple'=> false,
                'expanded' => false,
                'required' => false,
                'empty_value' => '購入間隔を選択してください',
                'empty_data' => '',
                'constraints' => array(
                    new Assert\NotBlank(array('message' => '購入間隔が選択されていません。')),
                ),
            ))
            ->add('periodic_create_day', 'choice', array(
                'label' => '次回注文基準日',
                'choices' => $arrCreateDay,
                'multiple'=> false,
                'expanded' => false,
                'required' => false,
                'empty_value' => '次回注文基準日を選択してください',
                'empty_data' => '',
            ))
            ->add('quantity', 'number', array(
                'label' => '数量',
                'required' => true,
                'constraints' => array(
                    new Assert\NotBlank(array('message' => '数量が入力されていません。')),
                    new Assert\Regex(array(
                        'pattern' => "/^\d+$/u",
                        'message' => 'form.type.numeric.invalid'
                    )),
                ),
            ))
            ->add('price', 'number', array(
                'label' => '価格（単価）',
                'required' => true,
                'constraints' => array(
                    new Assert\NotBlank(array('message' => '価格（単価）が入力されていません。')),
                    new Assert\Regex(array(
                        'pattern' => "/^\d+$/u",
                        'message' => 'form.type.numeric.invalid'
                    )),
                ),
            ))
            ->add('name01', 'text', array(
                'label' => 'お名前（姓）',
                'required' => false,
                'constraints' => array(
                    new Assert\NotBlank(array('message' => 'お名前（姓）が入力されていません。')),
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->add('name02', 'text', array(
                'label' => 'お名前（名）',
                'required' => false,
                'constraints' => array(
                    new Assert\NotBlank(array('message' => 'お名前（名）が入力されていません。')),
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->add('kana01', 'text', array(
                'label' => 'お名前（セイ）',
                'required' => false,
                'constraints' => array(
                    new Assert\NotBlank(array('message' => 'お名前（セイ）が入力されていません。')),
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->add('kana02', 'text', array(
                'label' => 'お名前（メイ）',
                'required' => false,
                'constraints' => array(
                    new Assert\NotBlank(array('message' => 'お名前（名）が入力されていません。')),
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->add('pref', 'choice', array(
                'label' => '都道府県',
                'choices' => $pref,
                'multiple'=> false,
                'expanded' => false,
                'required' => false,
                'empty_value' => '都道府県を選択してください',
                'empty_data' => '',
            ))
            ->add('zip01', 'text', array(
                'label' => '郵便番号01',
                'required' => false,
                'constraints' => array(
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->add('zip02', 'text', array(
                'label' => '郵便番号2',
                'required' => false,
                'constraints' => array(
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->add('addr01', 'text', array(
                'label' => '住所01',
                'required' => false,
                'constraints' => array(
                    new Assert\Length(array(
                        'max' => $config['mtext_len'],
                    ))
                ),
            ))
            ->add('addr02', 'text', array(
                'label' => '住所02',
                'required' => false,
                'constraints' => array(
                    new Assert\Length(array(
                        'max' => $config['mtext_len'],
                    ))
                ),
            ))
            ->add('tel01', 'text', array(
                'label' => '電話番号01',
                'required' => false,
                'constraints' => array(
                    new Assert\NotBlank(array('message' => '電話番号01が入力されていません。')),
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->add('tel02', 'text', array(
                'label' => '電話番号02',
                'required' => false,
                'constraints' => array(
                    new Assert\NotBlank(array('message' => '電話番号02が入力されていません。')),
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->add('tel03', 'text', array(
                'label' => '電話番号03',
                'required' => false,
                'constraints' => array(
                    new Assert\NotBlank(array('message' => '電話番号03が入力されていません。')),
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->add('fax01', 'text', array(
                'label' => 'FAX番号01',
                'required' => false,
                'constraints' => array(
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->add('fax02', 'text', array(
                'label' => 'FAX番号02',
                'required' => false,
                'constraints' => array(
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->add('fax03', 'text', array(
                'label' => 'FAX番号03',
                'required' => false,
                'constraints' => array(
                    new Assert\Length(array(
                        'max' => $config['stext_len'],
                    ))
                ),
            ))
            ->addEventSubscriber(new \Eccube\Event\FormEventSubscriber());
    }

    /**
     * {@inheritdoc}
     */
    public function getName()
    {
        return 'admin_periodic_info_edit';
    }
}
?>
