<?php
/*
 * Copyright(c) 2015 PAYDESIGN, Inc. All rights reserved.
 * http://www.paydesign.co.jp/
 */

namespace Plugin\PayDesign\Repository;

use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query;

/**
 * PayDesignPaymentMethodRepository
 *
 * This class was generated by the Doctrine ORM. Add your own custom
 * repository methods below.
 */
class PayDesignPaymentMethodRepository extends EntityRepository {

    /**
     * @var array array of configs
     */
    private $config;

    /**
     * Set the config of this repository
     * @param array $config
     */
    public function setConfig(array $config)
    {
        $this->config = $config;
    }

    /**
     * Find or create payment method
     *
     * @param type $id
     * @return type
     */
    public function findOrCreate($id) {

        if ($id == 0) {
            $now = new \DateTime();
            $Payment = new \Plugin\PayDesign\Entity\PayDesignPaymentMethod();
            $Payment
                ->setDelFlg(0)
                ->setUpdateDate($now)
                ->setCreateDate($now);
        } else {
            $Payment = $this->find($id);
        }

        return $Payment;
    }

    /**
     * find all
     *
     * @return type
     */
    public function findAllArray() {

        $query = $this
            ->getEntityManager()
            ->createQuery('SELECT p FROM Eccube\Entity\Payment p INDEX BY p.id');
        $result = $query
            ->getResult(Query::HYDRATE_ARRAY);

        return $result;
    }

    /**
     * Find mul pay payment
     *
     * @return type
     */
    public function findMulPayPayments() {

        $qb = $this->createQueryBuilder('p');
        $qb
            ->where($qb->expr()->andx(
                $qb->expr()->eq('p.del_flg', 0),
                $qb->expr()->eq('p.code', ':code'))
            )
            ->setParameter('code', $this->config['PDP_CODE']);

        return $qb->getQuery()->getResult();
    }

    /**
     * Get all payment_id of table dtb_payment base on plugin_code of table plg_paydesign_payment_method
     *
     * @param bool $incDel Flag for counting deleted record
     * @return array()
     */
    public function getPaymentByCode($incDel,$app) {

        $softDeleteFilter = $app['orm.em']->getFilters()->getFilter('soft_delete');
        $originExcludes = $softDeleteFilter->getExcludes();

        if ($incDel){
            $softDeleteFilter->setExcludes(array(
                'Eccube\Entity\Payment',
                'Plugin\PayDesign\Entity\PayDesignPaymentMethod'
            ));
        }

        $qb = $this->getEntityManager()->createQueryBuilder();
        $qb
            ->select('p.id')
            ->from('\Eccube\Entity\Payment', 'p')
            ->innerJoin('\Plugin\PayDesign\Entity\PayDesignPaymentMethod', 'g', 'WITH', 'p.id = g.id')
            ->where($qb->expr()->andx(
                $qb->expr()->eq('g.code', ':code'))
            );
        $qb->setParameter('code', $this->config['PDP_CODE']);

        $ret = $qb
            ->getQuery()
            ->getResult();

        if ($incDel){
            $softDeleteFilter->setExcludes($originExcludes);
        }

        return $ret;
    }

    /**
     * Get payment by type, with option to including or excluding deleted record
     *
     * @param type $paymentTypeId
     * @param type $app
     * @return type
     */
    public function getPaymentByType($paymentTypeId, $incDel, $app) {

        $softDeleteFilter = $app['orm.em']->getFilters()->getFilter('soft_delete');
        $originExcludes = $softDeleteFilter->getExcludes();

        if ($incDel){
            $softDeleteFilter->setExcludes(array(
                'Eccube\Entity\Payment',
                'Plugin\PayDesign\Entity\PayDesignPaymentMethod'
            ));
        }

        $qb = $this->getEntityManager()->createQueryBuilder();
        $qb
            ->select('p')
            ->from('\Eccube\Entity\Payment', 'p')
            ->join('\Plugin\PayDesign\Entity\PayDesignPaymentMethod', 'g', 'WITH', 'p.id = g.id')
            ->where(
                $qb->expr()->eq('g.memo03', ':x')
            );
        $qb->setParameter('x', $paymentTypeId);

        $ret = $qb
            ->getQuery()
            ->setMaxResults(1)
            ->getOneOrNullResult();

        if ($incDel){
            $softDeleteFilter->setExcludes($originExcludes);
        }

        return $ret;
    }

    public function getPayDesignPayment($field, $value, $incDel, $app) {

        $softDeleteFilter = $app['orm.em']->getFilters()->getFilter('soft_delete');
        $originExcludes = $softDeleteFilter->getExcludes();

        if ($incDel){
            $softDeleteFilter->setExcludes(array(
                'Plugin\PayDesign\Entity\PayDesignPaymentMethod'
            ));
        }

        $PayDesignPayment = $app['eccube.plugin.paydesign.repository.paydesign_payment_method']->findOneBy(array($field => $value));

        if ($incDel){
            $softDeleteFilter->setExcludes($originExcludes);
        }

        return $PayDesignPayment;

    }

    /**
     * Get payment list
     *
     * @return type
     */
    public function getPaymentList() {

        $qb = $this->getEntityManager()->createQueryBuilder();
        $qb
            ->select('p.id')
            ->from('\Eccube\Entity\Payment', 'p')
            ->join('\Plugin\PayDesign\Entity\PayDesignPaymentMethod', 'g', 'WITH', 'p.id = g.id')
            ->where(
                $qb->expr()->eq('g.code', ':x')
            );
        $qb->setParameter('x', $this->config['PDP_CODE']);
        return $qb
            ->getQuery()
            ->getArrayResult();
    }

    /**
     * Delete payment
     *
     * @param type $paymentId
     * @return boolean
     */
    public function deletePayment($paymentId) {

        $qb = $this->getEntityManager()->createQueryBuilder();
        $qb
            ->select('p')
            ->from('\Eccube\Entity\Payment', 'p')
            ->where($qb->expr()->andx(
                $qb->expr()->eq('p.del_flg', 0),
                $qb->expr()->eq('p.id', ':id'))
            );
        $qb->setParameter('id', $paymentId);

        try {
            $Payment = $qb
                ->getQuery()
                ->setMaxResults(1)
                ->getSingleResult();

        } catch (\Exception $e) {
            return false;
        }

        $em = $this->getEntityManager();
        $em->remove($Payment);
        $em->flush();

        return true;
    }
}
?>
