<?php
/*
 * Copyright(c) 2015 PAYDESIGN, Inc. All rights reserved.
 * http://www.paydesign.co.jp/
 */

namespace Plugin\PayDesign\Repository;

use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query;

/**
 * PayDesignPeriodicInfoRepository
 *
 * This class was generated by the Doctrine ORM. Add your own custom
 * repository methods below.
 */
class PayDesignPeriodicInfoRepository extends EntityRepository {

    /** @var array */
    public $config;

    public function setConfig(array $config)
    {
        $this->config = $config;
    }

    /**
     * 定期マスタ検索
     * @param  array $searchData
     * @return QueryBuilder
     */
    public function getQueryBuilderBySearchDataForAdmin($searchData)
    {
        $qb = $this->createQueryBuilder('p');

        // periodic_id_start
        if (!empty($searchData['periodic_id_start']) && $searchData['periodic_id_start']) {
            $qb
                ->andWhere('p.id >= :periodic_id_start')
                ->setParameter('periodic_id_start', $searchData['periodic_id_start']);
        }

        // multi
        if (!empty($searchData['multi']) && $searchData['multi']) {
            $multi = preg_match('/^\d+$/', $searchData['multi']) ? $searchData['multi'] : null;
            $qb
                ->leftJoin('p.Customer', 'c')
                ->andWhere('p.id = :multi OR c.name01 LIKE :likemulti OR c.name02 LIKE :likemulti OR ' .
                           'c.kana01 LIKE :likemulti OR c.kana02 LIKE :likemulti')
                ->setParameter('multi', $multi)
                ->setParameter('likemulti', '%' . $searchData['multi'] . '%');
        }

        // status
        if (!empty($searchData['status']) && $searchData['status']) {
            $qb
                ->andWhere('p.periodic_status = :status')
                ->setParameter('status', $searchData['status']);
        }

        // name
        if (!empty($searchData['name']) && $searchData['name']) {
            $qb
                ->leftJoin('p.Customer', 'c')
                ->andWhere('CONCAT(c.name01, c.name02) LIKE :name')
                ->setParameter('name', '%' . $searchData['name'] . '%');
        }

        // kana
        if (!empty($searchData['kana']) && $searchData['kana']) {
            $qb
                ->leftJoin('p.Customer', 'c')
                ->andWhere('CONCAT(c.kana01, c.kana02) LIKE :kana')
                ->setParameter('kana', '%' . $searchData['kana'] . '%');
        }

        // email
        if (!empty($searchData['email']) && $searchData['email']) {
            $qb
                ->leftJoin('p.Customer', 'c')
                ->andWhere('c.email LIKE :email')
                ->setParameter('email', '%' . $searchData['email'] . '%');
        }

        // periodic_next_date
        if (!empty($searchData['periodic_next_date_start']) && $searchData['periodic_next_date_start']) {
            $date = $searchData['periodic_next_date_start']
                ->format('Y-m-d H:i:s');
            $qb
                ->andWhere('p.periodic_next_date >= :periodic_next_date_start')
                ->setParameter('periodic_next_date_start', $date);
        }
        if (!empty($searchData['periodic_next_date_end']) && $searchData['periodic_next_date_end']) {
            $date = $searchData['periodic_next_date_end']
                ->modify('+1 days')
                ->format('Y-m-d H:i:s');
            $qb
                ->andWhere('p.periodic_next_date < :periodic_next_date_end')
                ->setParameter('periodic_next_date_end', $date);
        }

        // tel
        /*
        if (!empty($searchData['tel01']) && $searchData['tel01']) {
            $qb
                ->leftJoin('p.Customer', 'c')
                ->andWhere('c.tel01 LIKE :tel01')
                ->setParameter('tel01', '%' . $searchData['tel01'] . '%');
        }
        if (!empty($searchData['tel02']) && $searchData['tel02']) {
            $qb
                ->leftJoin('p.Customer', 'c')
                ->andWhere('c.tel02 LIKE :tel02')
                ->setParameter('tel02', '%' . $searchData['tel02'] . '%');
        }
        if (!empty($searchData['tel03']) && $searchData['tel03']) {
            $qb
                ->leftJoin('p.Customer', 'c')
                ->andWhere('c.tel03 LIKE :tel03')
                ->setParameter('tel03', '%' . $searchData['tel03'] . '%');
        }
        */
        if (!empty($searchData['tel']) && $searchData['tel']) {
            $qb
                ->leftJoin('p.Customer', 'c')
                ->andWhere('CONCAT(c.tel01, c.tel02, c.tel03) LIKE :tel')
                ->setParameter('tel', '%' . $searchData['tel'] . '%');
        }

        // payment
        if (!empty($searchData['payment']) && count($searchData['payment'])) {
            $payments = array();
            foreach ($searchData['payment'] as $payment) {
                $payments[] = $payment->getId();
            }
            $qb
                ->andWhere($qb->expr()->in('p.payment_id', ':payments'))
                ->setParameter('payments', $payments);
        }

        // product_price
        if (!empty($searchData['product_price_start']) && $searchData['product_price_start']) {
            $qb
                ->andWhere('p.price >= :product_price_start')
                ->setParameter('product_price_start', $searchData['product_price_start']);
        }
        if (!empty($searchData['product_price_end']) && $searchData['product_price_end']) {
            $qb
                ->andWhere('p.price <= :product_price_end')
                ->setParameter('product_price_end', $searchData['product_price_end']);
        }

        // buy_product_name
        if (!empty($searchData['buy_product_name']) && $searchData['buy_product_name']) {
            $qb
                ->andWhere('p.product_name LIKE :buy_product_name')
                ->setParameter('buy_product_name', $searchData['buy_product_name']);
        }

        // Order By
        $qb->addOrderBy('p.update_date', 'DESC');

        return $qb;
    }

    /**
     * 定期注文データ作成時検索
     * @param  array $searchData
     * @return QueryBuilder
     */
    public function getQueryBuilderBySearchCreateDataForAdmin($searchData)
    {
        $qb = $this->createQueryBuilder('p');

        // periodic_next_date
        if (!empty($searchData['periodic_next_date_start']) && $searchData['periodic_next_date_start']) {
            $date = $searchData['periodic_next_date_start']
                ->format('Y-m-d H:i:s');
            $qb
                ->andWhere('p.periodic_next_date >= :periodic_next_date_start')
                ->setParameter('periodic_next_date_start', $date);
        }
        if (!empty($searchData['periodic_next_date_end']) && $searchData['periodic_next_date_end']) {
            $date = $searchData['periodic_next_date_end']
                ->modify('+1 days')
                ->format('Y-m-d H:i:s');
            $qb
                ->andWhere('p.periodic_next_date < :periodic_next_date_end')
                ->setParameter('periodic_next_date_end', $date);
        }

        // status (【継続中】固定で強制設定)
        $qb
            ->andWhere('p.periodic_status = :status')
            ->setParameter('status', 1);

        // Order By
        $qb->addOrderBy('p.update_date', 'DESC');

        return $qb;
    }

    /**
     * 指定した会員(ID)の有効定期マスタデータ検索
     * @param  array $searchData
     * @return QueryBuilder
     */
    public function getQueryBuilderBySearchEnablePeriodicData($customer_id)
    {
        $qb = $this->createQueryBuilder('p');

        // 会員ID
        if( !is_null($customer_id) && $customer_id > 0 ) {
            $qb
                ->andWhere('p.customer_id = :customer_id')
                ->setParameter('customer_id', $customer_id);
        }

        // status (【継続中(1)】・【停止(2)】固定で強制設定)
        $qb
            ->andWhere('p.periodic_status = :status1 OR p.periodic_status = :status2')
            ->setParameter('status1', 1)
            ->setParameter('status2', 2);

        // Order By
        $qb->addOrderBy('p.update_date', 'DESC');

        return $qb;
    }
}
?>
